[ofa-general] [PATCH 27/28] IB/ipath - when we check for LID availability, check for lack of interrupts too.

Arthur Jones arthur.jones at qlogic.com
Tue Jun 19 16:43:10 PDT 2007


All too often, interrupts do not get enabled for our card due
to bios misconfiguration and other issues.  This patch checks
for that condition on startup when checking for LID availability
and warns the user.

Signed-off-by: Arthur Jones <arthur.jones at qlogic.com>
---

 drivers/infiniband/hw/ipath/ipath_driver.c |    8 +++++---
 drivers/infiniband/hw/ipath/ipath_intr.c   |    3 +++
 drivers/infiniband/hw/ipath/ipath_kernel.h |    3 +++
 3 files changed, 11 insertions(+), 3 deletions(-)

diff --git a/drivers/infiniband/hw/ipath/ipath_intr.c b/drivers/infiniband/hw/ipath/ipath_intr.c
index f8aac8e..ced591d 100644
--- a/drivers/infiniband/hw/ipath/ipath_intr.c
+++ b/drivers/infiniband/hw/ipath/ipath_intr.c
@@ -932,6 +932,9 @@ irqreturn_t ipath_intr(int irq, void *data)
 
 	ipath_stats.sps_ints++;
 
+	if (dd->ipath_int_counter != (u32) -1)
+		dd->ipath_int_counter++;
+
 	if (!(dd->ipath_flags & IPATH_PRESENT)) {
 		/*
 		 * This return value is not great, but we do not want the
diff --git a/drivers/infiniband/hw/ipath/ipath_kernel.h b/drivers/infiniband/hw/ipath/ipath_kernel.h
index f261af1..381c97e 100644
--- a/drivers/infiniband/hw/ipath/ipath_kernel.h
+++ b/drivers/infiniband/hw/ipath/ipath_kernel.h
@@ -297,6 +297,9 @@ struct ipath_devdata {
 	u32 ipath_lastport_piobuf;
 	/* is a stats timer active */
 	u32 ipath_stats_timer_active;
+	atomic_t ipath_rewrite_timer_active;
+	/* number of interrupts for this device -- saturates... */
+	u32 ipath_int_counter;
 	/* dwords sent read from counter */
 	u32 ipath_lastsword;
 	/* dwords received read from counter */




More information about the general mailing list
diff --git a/drivers/infiniband/hw/ipath/ipath_driver.c b/drivers/infiniband/hw/ipath/ipath_driver.c
index 1d2369b..825ed4d 100644
--- a/drivers/infiniband/hw/ipath/ipath_driver.c
+++ b/drivers/infiniband/hw/ipath/ipath_driver.c
@@ -141,11 +141,13 @@ static void check_link_status(struct work_struct *work)
 	}
 
 	/*
 	 * If we don't have a LID, let the user know and don't bother
 	 * checking again.
 	 */
 
-	if (dd->ipath_lid == 0)
+	if (dd->ipath_int_counter == 0)
+		dev_err(&dd->pcidev->dev, "No interrupts detected.\n");
+	else if (dd->ipath_lid == 0)
 		dev_info(&dd->pcidev->dev,
 			 "We don't have a LID yet (no subnet manager?)\n");
 	else if (!(*dd->ipath_statusp & IPATH_STATUS_IB_READY))
@@ -141,11 +141,13 @@ static void check_link_status(struct work_struct *work)
 
 	/*
-	 * If we don't have a LID, let the user know and don't bother
-	 * checking again.
+	 * If we don't have a LID or interrupts, let the user know and
+	 * don't bother checking again.
 	 */
 